{ nixos-unstable, nixpkgs, home-manager, ... }:

{
  mkHost = {name}: 
  let
    system = "x86_64-linux";

    unstable = import nixos-unstable { 
      inherit system; 
      config.allowUnfree = true; 
    };

    pkgs = import nixpkgs { 
      inherit system; 
      config.allowUnfree = true; 
      overlays = [ (final: prev: { inherit unstable; }) ];
    };
  in nixpkgs.lib.nixosSystem {
    inherit system;
    modules = [ 
      {
        nixpkgs.pkgs = pkgs;
        nix.nixPath = [ 
          "nixpkgs=${nixpkgs}" 
          "unstable=${nixos-unstable}"
        ];
        nix.registry.nixpkgs.flake = nixpkgs;
        nix.registry.unstable.flake = nixos-unstable;
      }

      ./common.nix
      ./users.nix
      home-manager.nixosModules.home-manager
      ./hosts/${name}/default.nix
      ./acme.nix
    ];
  };
}
